import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class SasportalResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class CustomersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DeploymentsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class DevicesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: SasPortalDevice = ...,
                    **kwargs: typing.Any
                ) -> SasPortalDeviceHttpRequest: ...
                def createSigned(
                    self,
                    *,
                    parent: str,
                    body: SasPortalCreateSignedDeviceRequest = ...,
                    **kwargs: typing.Any
                ) -> SasPortalDeviceHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> SasPortalListDevicesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: SasPortalListDevicesResponseHttpRequest,
                    previous_response: SasPortalListDevicesResponse,
                ) -> SasPortalListDevicesResponseHttpRequest | None: ...

            def create(
                self,
                *,
                parent: str,
                body: SasPortalDeployment = ...,
                **kwargs: typing.Any
            ) -> SasPortalDeploymentHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> SasPortalEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> SasPortalDeploymentHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> SasPortalListDeploymentsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: SasPortalListDeploymentsResponseHttpRequest,
                previous_response: SasPortalListDeploymentsResponse,
            ) -> SasPortalListDeploymentsResponseHttpRequest | None: ...
            def move(
                self,
                *,
                name: str,
                body: SasPortalMoveDeploymentRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalOperationHttpRequest: ...
            def patch(
                self,
                *,
                name: str,
                body: SasPortalDeployment = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> SasPortalDeploymentHttpRequest: ...
            def devices(self) -> DevicesResource: ...

        @typing.type_check_only
        class DevicesResource(googleapiclient.discovery.Resource):
            def create(
                self, *, parent: str, body: SasPortalDevice = ..., **kwargs: typing.Any
            ) -> SasPortalDeviceHttpRequest: ...
            def createSigned(
                self,
                *,
                parent: str,
                body: SasPortalCreateSignedDeviceRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalDeviceHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> SasPortalEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> SasPortalDeviceHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> SasPortalListDevicesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: SasPortalListDevicesResponseHttpRequest,
                previous_response: SasPortalListDevicesResponse,
            ) -> SasPortalListDevicesResponseHttpRequest | None: ...
            def move(
                self,
                *,
                name: str,
                body: SasPortalMoveDeviceRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalOperationHttpRequest: ...
            def patch(
                self,
                *,
                name: str,
                body: SasPortalDevice = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> SasPortalDeviceHttpRequest: ...
            def signDevice(
                self,
                *,
                name: str,
                body: SasPortalSignDeviceRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalEmptyHttpRequest: ...
            def updateSigned(
                self,
                *,
                name: str,
                body: SasPortalUpdateSignedDeviceRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalDeviceHttpRequest: ...

        @typing.type_check_only
        class NodesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class DeploymentsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: SasPortalDeployment = ...,
                    **kwargs: typing.Any
                ) -> SasPortalDeploymentHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> SasPortalListDeploymentsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: SasPortalListDeploymentsResponseHttpRequest,
                    previous_response: SasPortalListDeploymentsResponse,
                ) -> SasPortalListDeploymentsResponseHttpRequest | None: ...

            @typing.type_check_only
            class DevicesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: SasPortalDevice = ...,
                    **kwargs: typing.Any
                ) -> SasPortalDeviceHttpRequest: ...
                def createSigned(
                    self,
                    *,
                    parent: str,
                    body: SasPortalCreateSignedDeviceRequest = ...,
                    **kwargs: typing.Any
                ) -> SasPortalDeviceHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> SasPortalListDevicesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: SasPortalListDevicesResponseHttpRequest,
                    previous_response: SasPortalListDevicesResponse,
                ) -> SasPortalListDevicesResponseHttpRequest | None: ...

            @typing.type_check_only
            class NodesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: SasPortalNode = ...,
                    **kwargs: typing.Any
                ) -> SasPortalNodeHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> SasPortalListNodesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: SasPortalListNodesResponseHttpRequest,
                    previous_response: SasPortalListNodesResponse,
                ) -> SasPortalListNodesResponseHttpRequest | None: ...

            def create(
                self, *, parent: str, body: SasPortalNode = ..., **kwargs: typing.Any
            ) -> SasPortalNodeHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> SasPortalEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> SasPortalNodeHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> SasPortalListNodesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: SasPortalListNodesResponseHttpRequest,
                previous_response: SasPortalListNodesResponse,
            ) -> SasPortalListNodesResponseHttpRequest | None: ...
            def move(
                self,
                *,
                name: str,
                body: SasPortalMoveNodeRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalOperationHttpRequest: ...
            def patch(
                self,
                *,
                name: str,
                body: SasPortalNode = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> SasPortalNodeHttpRequest: ...
            def deployments(self) -> DeploymentsResource: ...
            def devices(self) -> DevicesResource: ...
            def nodes(self) -> NodesResource: ...

        def get(
            self, *, name: str, **kwargs: typing.Any
        ) -> SasPortalCustomerHttpRequest: ...
        def list(
            self, *, pageSize: int = ..., pageToken: str = ..., **kwargs: typing.Any
        ) -> SasPortalListCustomersResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: SasPortalListCustomersResponseHttpRequest,
            previous_response: SasPortalListCustomersResponse,
        ) -> SasPortalListCustomersResponseHttpRequest | None: ...
        def patch(
            self,
            *,
            name: str,
            body: SasPortalCustomer = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> SasPortalCustomerHttpRequest: ...
        def deployments(self) -> DeploymentsResource: ...
        def devices(self) -> DevicesResource: ...
        def nodes(self) -> NodesResource: ...

    @typing.type_check_only
    class DeploymentsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DevicesResource(googleapiclient.discovery.Resource):
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> SasPortalEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> SasPortalDeviceHttpRequest: ...
            def move(
                self,
                *,
                name: str,
                body: SasPortalMoveDeviceRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalOperationHttpRequest: ...
            def patch(
                self,
                *,
                name: str,
                body: SasPortalDevice = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> SasPortalDeviceHttpRequest: ...
            def signDevice(
                self,
                *,
                name: str,
                body: SasPortalSignDeviceRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalEmptyHttpRequest: ...
            def updateSigned(
                self,
                *,
                name: str,
                body: SasPortalUpdateSignedDeviceRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalDeviceHttpRequest: ...

        def get(
            self, *, name: str, **kwargs: typing.Any
        ) -> SasPortalDeploymentHttpRequest: ...
        def devices(self) -> DevicesResource: ...

    @typing.type_check_only
    class InstallerResource(googleapiclient.discovery.Resource):
        def generateSecret(
            self, *, body: SasPortalGenerateSecretRequest = ..., **kwargs: typing.Any
        ) -> SasPortalGenerateSecretResponseHttpRequest: ...
        def validate(
            self, *, body: SasPortalValidateInstallerRequest = ..., **kwargs: typing.Any
        ) -> SasPortalValidateInstallerResponseHttpRequest: ...

    @typing.type_check_only
    class NodesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DeploymentsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class DevicesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: SasPortalDevice = ...,
                    **kwargs: typing.Any
                ) -> SasPortalDeviceHttpRequest: ...
                def createSigned(
                    self,
                    *,
                    parent: str,
                    body: SasPortalCreateSignedDeviceRequest = ...,
                    **kwargs: typing.Any
                ) -> SasPortalDeviceHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> SasPortalListDevicesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: SasPortalListDevicesResponseHttpRequest,
                    previous_response: SasPortalListDevicesResponse,
                ) -> SasPortalListDevicesResponseHttpRequest | None: ...

            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> SasPortalEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> SasPortalDeploymentHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> SasPortalListDeploymentsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: SasPortalListDeploymentsResponseHttpRequest,
                previous_response: SasPortalListDeploymentsResponse,
            ) -> SasPortalListDeploymentsResponseHttpRequest | None: ...
            def move(
                self,
                *,
                name: str,
                body: SasPortalMoveDeploymentRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalOperationHttpRequest: ...
            def patch(
                self,
                *,
                name: str,
                body: SasPortalDeployment = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> SasPortalDeploymentHttpRequest: ...
            def devices(self) -> DevicesResource: ...

        @typing.type_check_only
        class DevicesResource(googleapiclient.discovery.Resource):
            def create(
                self, *, parent: str, body: SasPortalDevice = ..., **kwargs: typing.Any
            ) -> SasPortalDeviceHttpRequest: ...
            def createSigned(
                self,
                *,
                parent: str,
                body: SasPortalCreateSignedDeviceRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalDeviceHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> SasPortalEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> SasPortalDeviceHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> SasPortalListDevicesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: SasPortalListDevicesResponseHttpRequest,
                previous_response: SasPortalListDevicesResponse,
            ) -> SasPortalListDevicesResponseHttpRequest | None: ...
            def move(
                self,
                *,
                name: str,
                body: SasPortalMoveDeviceRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalOperationHttpRequest: ...
            def patch(
                self,
                *,
                name: str,
                body: SasPortalDevice = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> SasPortalDeviceHttpRequest: ...
            def signDevice(
                self,
                *,
                name: str,
                body: SasPortalSignDeviceRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalEmptyHttpRequest: ...
            def updateSigned(
                self,
                *,
                name: str,
                body: SasPortalUpdateSignedDeviceRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalDeviceHttpRequest: ...

        @typing.type_check_only
        class NodesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class DeploymentsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: SasPortalDeployment = ...,
                    **kwargs: typing.Any
                ) -> SasPortalDeploymentHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> SasPortalListDeploymentsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: SasPortalListDeploymentsResponseHttpRequest,
                    previous_response: SasPortalListDeploymentsResponse,
                ) -> SasPortalListDeploymentsResponseHttpRequest | None: ...

            @typing.type_check_only
            class DevicesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: SasPortalDevice = ...,
                    **kwargs: typing.Any
                ) -> SasPortalDeviceHttpRequest: ...
                def createSigned(
                    self,
                    *,
                    parent: str,
                    body: SasPortalCreateSignedDeviceRequest = ...,
                    **kwargs: typing.Any
                ) -> SasPortalDeviceHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> SasPortalListDevicesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: SasPortalListDevicesResponseHttpRequest,
                    previous_response: SasPortalListDevicesResponse,
                ) -> SasPortalListDevicesResponseHttpRequest | None: ...

            @typing.type_check_only
            class NodesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: SasPortalNode = ...,
                    **kwargs: typing.Any
                ) -> SasPortalNodeHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> SasPortalListNodesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: SasPortalListNodesResponseHttpRequest,
                    previous_response: SasPortalListNodesResponse,
                ) -> SasPortalListNodesResponseHttpRequest | None: ...

            def create(
                self, *, parent: str, body: SasPortalNode = ..., **kwargs: typing.Any
            ) -> SasPortalNodeHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> SasPortalEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> SasPortalNodeHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> SasPortalListNodesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: SasPortalListNodesResponseHttpRequest,
                previous_response: SasPortalListNodesResponse,
            ) -> SasPortalListNodesResponseHttpRequest | None: ...
            def move(
                self,
                *,
                name: str,
                body: SasPortalMoveNodeRequest = ...,
                **kwargs: typing.Any
            ) -> SasPortalOperationHttpRequest: ...
            def patch(
                self,
                *,
                name: str,
                body: SasPortalNode = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> SasPortalNodeHttpRequest: ...
            def deployments(self) -> DeploymentsResource: ...
            def devices(self) -> DevicesResource: ...
            def nodes(self) -> NodesResource: ...

        def get(
            self, *, name: str, **kwargs: typing.Any
        ) -> SasPortalNodeHttpRequest: ...
        def deployments(self) -> DeploymentsResource: ...
        def devices(self) -> DevicesResource: ...
        def nodes(self) -> NodesResource: ...

    @typing.type_check_only
    class PoliciesResource(googleapiclient.discovery.Resource):
        def get(
            self, *, body: SasPortalGetPolicyRequest = ..., **kwargs: typing.Any
        ) -> SasPortalPolicyHttpRequest: ...
        def set(
            self, *, body: SasPortalSetPolicyRequest = ..., **kwargs: typing.Any
        ) -> SasPortalPolicyHttpRequest: ...
        def test(
            self, *, body: SasPortalTestPermissionsRequest = ..., **kwargs: typing.Any
        ) -> SasPortalTestPermissionsResponseHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def customers(self) -> CustomersResource: ...
    def deployments(self) -> DeploymentsResource: ...
    def installer(self) -> InstallerResource: ...
    def nodes(self) -> NodesResource: ...
    def policies(self) -> PoliciesResource: ...

@typing.type_check_only
class SasPortalCustomerHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SasPortalCustomer: ...

@typing.type_check_only
class SasPortalDeploymentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SasPortalDeployment: ...

@typing.type_check_only
class SasPortalDeviceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SasPortalDevice: ...

@typing.type_check_only
class SasPortalEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SasPortalEmpty: ...

@typing.type_check_only
class SasPortalGenerateSecretResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SasPortalGenerateSecretResponse: ...

@typing.type_check_only
class SasPortalListCustomersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SasPortalListCustomersResponse: ...

@typing.type_check_only
class SasPortalListDeploymentsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SasPortalListDeploymentsResponse: ...

@typing.type_check_only
class SasPortalListDevicesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SasPortalListDevicesResponse: ...

@typing.type_check_only
class SasPortalListNodesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SasPortalListNodesResponse: ...

@typing.type_check_only
class SasPortalNodeHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SasPortalNode: ...

@typing.type_check_only
class SasPortalOperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SasPortalOperation: ...

@typing.type_check_only
class SasPortalPolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SasPortalPolicy: ...

@typing.type_check_only
class SasPortalTestPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SasPortalTestPermissionsResponse: ...

@typing.type_check_only
class SasPortalValidateInstallerResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SasPortalValidateInstallerResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleIamAdminV1AuditData(typing_extensions.TypedDict, total=False):
    permissionDelta: GoogleIamAdminV1AuditDataPermissionDelta

@typing.type_check_only
class GoogleIamAdminV1AuditDataPermissionDelta(
    typing_extensions.TypedDict, total=False
):
    addedPermissions: _list[str]
    removedPermissions: _list[str]

@typing.type_check_only
class GoogleIamV1BindingDelta(typing_extensions.TypedDict, total=False):
    action: typing_extensions.Literal["ACTION_UNSPECIFIED", "ADD", "REMOVE"]
    condition: GoogleTypeExpr
    member: str
    role: str

@typing.type_check_only
class GoogleIamV1LoggingAuditData(typing_extensions.TypedDict, total=False):
    policyDelta: GoogleIamV1PolicyDelta

@typing.type_check_only
class GoogleIamV1PolicyDelta(typing_extensions.TypedDict, total=False):
    bindingDeltas: _list[GoogleIamV1BindingDelta]

@typing.type_check_only
class GoogleIamV1betaWorkloadIdentityPoolOperationMetadata(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleIamV2betaDenyRule(typing_extensions.TypedDict, total=False):
    denialCondition: GoogleTypeExpr
    deniedPermissions: _list[str]
    deniedPrincipals: _list[str]
    exceptionPermissions: _list[str]
    exceptionPrincipals: _list[str]

@typing.type_check_only
class GoogleIamV2betaListPoliciesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    policies: _list[GoogleIamV2betaPolicy]

@typing.type_check_only
class GoogleIamV2betaPolicy(typing_extensions.TypedDict, total=False):
    annotations: dict[str, typing.Any]
    createTime: str
    deleteTime: str
    displayName: str
    etag: str
    kind: str
    name: str
    rules: _list[GoogleIamV2betaPolicyRule]
    uid: str
    updateTime: str

@typing.type_check_only
class GoogleIamV2betaPolicyOperationMetadata(typing_extensions.TypedDict, total=False):
    createTime: str

@typing.type_check_only
class GoogleIamV2betaPolicyRule(typing_extensions.TypedDict, total=False):
    denyRule: GoogleIamV2betaDenyRule
    description: str

@typing.type_check_only
class GoogleLongrunningOperation(typing_extensions.TypedDict, total=False):
    done: bool
    error: GoogleRpcStatus
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class GoogleRpcStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class GoogleTypeExpr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class SasPortalAssignment(typing_extensions.TypedDict, total=False):
    members: _list[str]
    role: str

@typing.type_check_only
class SasPortalChannelWithScore(typing_extensions.TypedDict, total=False):
    frequencyRange: SasPortalFrequencyRange
    score: float

@typing.type_check_only
class SasPortalCreateSignedDeviceRequest(typing_extensions.TypedDict, total=False):
    encodedDevice: str
    installerId: str

@typing.type_check_only
class SasPortalCustomer(typing_extensions.TypedDict, total=False):
    displayName: str
    name: str
    sasUserIds: _list[str]

@typing.type_check_only
class SasPortalDeployment(typing_extensions.TypedDict, total=False):
    displayName: str
    frns: _list[str]
    name: str
    sasUserIds: _list[str]

@typing.type_check_only
class SasPortalDevice(typing_extensions.TypedDict, total=False):
    activeConfig: SasPortalDeviceConfig
    currentChannels: _list[SasPortalChannelWithScore]
    deviceMetadata: SasPortalDeviceMetadata
    displayName: str
    fccId: str
    grantRangeAllowlists: _list[SasPortalFrequencyRange]
    grants: _list[SasPortalDeviceGrant]
    name: str
    preloadedConfig: SasPortalDeviceConfig
    serialNumber: str
    state: typing_extensions.Literal[
        "DEVICE_STATE_UNSPECIFIED", "RESERVED", "REGISTERED", "DEREGISTERED"
    ]

@typing.type_check_only
class SasPortalDeviceAirInterface(typing_extensions.TypedDict, total=False):
    radioTechnology: typing_extensions.Literal[
        "RADIO_TECHNOLOGY_UNSPECIFIED",
        "E_UTRA",
        "CAMBIUM_NETWORKS",
        "FOUR_G_BBW_SAA_1",
        "NR",
        "DOODLE_CBRS",
        "CW",
        "REDLINE",
        "TARANA_WIRELESS",
    ]
    supportedSpec: str

@typing.type_check_only
class SasPortalDeviceConfig(typing_extensions.TypedDict, total=False):
    airInterface: SasPortalDeviceAirInterface
    callSign: str
    category: typing_extensions.Literal[
        "DEVICE_CATEGORY_UNSPECIFIED", "DEVICE_CATEGORY_A", "DEVICE_CATEGORY_B"
    ]
    installationParams: SasPortalInstallationParams
    isSigned: bool
    measurementCapabilities: _list[str]
    model: SasPortalDeviceModel
    state: typing_extensions.Literal[
        "DEVICE_CONFIG_STATE_UNSPECIFIED", "DRAFT", "FINAL"
    ]
    updateTime: str
    userId: str

@typing.type_check_only
class SasPortalDeviceGrant(typing_extensions.TypedDict, total=False):
    channelType: typing_extensions.Literal[
        "CHANNEL_TYPE_UNSPECIFIED", "CHANNEL_TYPE_GAA", "CHANNEL_TYPE_PAL"
    ]
    expireTime: str
    frequencyRange: SasPortalFrequencyRange
    grantId: str
    lastHeartbeatTransmitExpireTime: str
    maxEirp: float
    moveList: _list[SasPortalDpaMoveList]
    state: typing_extensions.Literal[
        "GRANT_STATE_UNSPECIFIED",
        "GRANT_STATE_GRANTED",
        "GRANT_STATE_TERMINATED",
        "GRANT_STATE_SUSPENDED",
        "GRANT_STATE_AUTHORIZED",
        "GRANT_STATE_EXPIRED",
    ]
    suspensionReason: _list[str]

@typing.type_check_only
class SasPortalDeviceMetadata(typing_extensions.TypedDict, total=False):
    antennaModel: str
    commonChannelGroup: str
    interferenceCoordinationGroup: str
    nrqzValidated: bool
    nrqzValidation: SasPortalNrqzValidation

@typing.type_check_only
class SasPortalDeviceModel(typing_extensions.TypedDict, total=False):
    firmwareVersion: str
    hardwareVersion: str
    name: str
    softwareVersion: str
    vendor: str

@typing.type_check_only
class SasPortalDpaMoveList(typing_extensions.TypedDict, total=False):
    dpaId: str
    frequencyRange: SasPortalFrequencyRange

@typing.type_check_only
class SasPortalEmpty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class SasPortalFrequencyRange(typing_extensions.TypedDict, total=False):
    highFrequencyMhz: float
    lowFrequencyMhz: float

@typing.type_check_only
class SasPortalGenerateSecretRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class SasPortalGenerateSecretResponse(typing_extensions.TypedDict, total=False):
    secret: str

@typing.type_check_only
class SasPortalGetPolicyRequest(typing_extensions.TypedDict, total=False):
    resource: str

@typing.type_check_only
class SasPortalInstallationParams(typing_extensions.TypedDict, total=False):
    antennaAzimuth: int
    antennaBeamwidth: int
    antennaDowntilt: int
    antennaGain: int
    antennaModel: str
    cpeCbsdIndication: bool
    eirpCapability: int
    height: float
    heightType: typing_extensions.Literal[
        "HEIGHT_TYPE_UNSPECIFIED", "HEIGHT_TYPE_AGL", "HEIGHT_TYPE_AMSL"
    ]
    horizontalAccuracy: float
    indoorDeployment: bool
    latitude: float
    longitude: float
    verticalAccuracy: float

@typing.type_check_only
class SasPortalListCustomersResponse(typing_extensions.TypedDict, total=False):
    customers: _list[SasPortalCustomer]
    nextPageToken: str

@typing.type_check_only
class SasPortalListDeploymentsResponse(typing_extensions.TypedDict, total=False):
    deployments: _list[SasPortalDeployment]
    nextPageToken: str

@typing.type_check_only
class SasPortalListDevicesResponse(typing_extensions.TypedDict, total=False):
    devices: _list[SasPortalDevice]
    nextPageToken: str

@typing.type_check_only
class SasPortalListNodesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    nodes: _list[SasPortalNode]

@typing.type_check_only
class SasPortalMoveDeploymentRequest(typing_extensions.TypedDict, total=False):
    destination: str

@typing.type_check_only
class SasPortalMoveDeviceRequest(typing_extensions.TypedDict, total=False):
    destination: str

@typing.type_check_only
class SasPortalMoveNodeRequest(typing_extensions.TypedDict, total=False):
    destination: str

@typing.type_check_only
class SasPortalNode(typing_extensions.TypedDict, total=False):
    displayName: str
    name: str
    sasUserIds: _list[str]

@typing.type_check_only
class SasPortalNrqzValidation(typing_extensions.TypedDict, total=False):
    caseId: str
    cpiId: str
    latitude: float
    longitude: float
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "DRAFT", "FINAL"]

@typing.type_check_only
class SasPortalOperation(typing_extensions.TypedDict, total=False):
    done: bool
    error: SasPortalStatus
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class SasPortalPolicy(typing_extensions.TypedDict, total=False):
    assignments: _list[SasPortalAssignment]
    etag: str

@typing.type_check_only
class SasPortalSetPolicyRequest(typing_extensions.TypedDict, total=False):
    disableNotification: bool
    policy: SasPortalPolicy
    resource: str

@typing.type_check_only
class SasPortalSignDeviceRequest(typing_extensions.TypedDict, total=False):
    device: SasPortalDevice

@typing.type_check_only
class SasPortalStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class SasPortalTestPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]
    resource: str

@typing.type_check_only
class SasPortalTestPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class SasPortalUpdateSignedDeviceRequest(typing_extensions.TypedDict, total=False):
    encodedDevice: str
    installerId: str

@typing.type_check_only
class SasPortalValidateInstallerRequest(typing_extensions.TypedDict, total=False):
    encodedSecret: str
    installerId: str
    secret: str

@typing.type_check_only
class SasPortalValidateInstallerResponse(typing_extensions.TypedDict, total=False): ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudIdentityResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class CustomersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class UserinvitationsResource(googleapiclient.discovery.Resource):
            def cancel(
                self,
                *,
                name: str,
                body: CancelUserInvitationRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> UserInvitationHttpRequest: ...
            def isInvitableUser(
                self, *, name: str, **kwargs: typing.Any
            ) -> IsInvitableUserResponseHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListUserInvitationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListUserInvitationsResponseHttpRequest,
                previous_response: ListUserInvitationsResponse,
            ) -> ListUserInvitationsResponseHttpRequest | None: ...
            def send(
                self,
                *,
                name: str,
                body: SendUserInvitationRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        def userinvitations(self) -> UserinvitationsResource: ...

    @typing.type_check_only
    class DevicesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DeviceUsersResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ClientStatesResource(googleapiclient.discovery.Resource):
                def get(
                    self, *, name: str, customer: str = ..., **kwargs: typing.Any
                ) -> ClientStateHttpRequest: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: ClientState = ...,
                    customer: str = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            def approve(
                self,
                *,
                name: str,
                body: ApproveDeviceUserRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def block(
                self,
                *,
                name: str,
                body: BlockDeviceUserRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def cancelWipe(
                self,
                *,
                name: str,
                body: CancelWipeDeviceUserRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> DeviceUserHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListDeviceUsersResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListDeviceUsersResponseHttpRequest,
                previous_response: ListDeviceUsersResponse,
            ) -> ListDeviceUsersResponseHttpRequest | None: ...
            def lookup(
                self,
                *,
                parent: str,
                androidId: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                rawResourceId: str = ...,
                userId: str = ...,
                **kwargs: typing.Any
            ) -> LookupSelfDeviceUsersResponseHttpRequest: ...
            def lookup_next(
                self,
                previous_request: LookupSelfDeviceUsersResponseHttpRequest,
                previous_response: LookupSelfDeviceUsersResponse,
            ) -> LookupSelfDeviceUsersResponseHttpRequest | None: ...
            def wipe(
                self,
                *,
                name: str,
                body: WipeDeviceUserRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def clientStates(self) -> ClientStatesResource: ...

        def cancelWipe(
            self,
            *,
            name: str,
            body: CancelWipeDeviceRequest = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def create(
            self, *, body: CreateDeviceRequest = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def delete(
            self, *, name: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def get(self, *, name: str, **kwargs: typing.Any) -> DeviceHttpRequest: ...
        def list(
            self,
            *,
            filter: str = ...,
            orderBy: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            view: typing_extensions.Literal[
                "VIEW_UNSPECIFIED", "COMPANY_INVENTORY", "USER_ASSIGNED_DEVICES"
            ] = ...,
            **kwargs: typing.Any
        ) -> ListDevicesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListDevicesResponseHttpRequest,
            previous_response: ListDevicesResponse,
        ) -> ListDevicesResponseHttpRequest | None: ...
        def wipe(
            self, *, name: str, body: WipeDeviceRequest = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def deviceUsers(self) -> DeviceUsersResource: ...

    @typing.type_check_only
    class GroupsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class MembershipsResource(googleapiclient.discovery.Resource):
            def checkTransitiveMembership(
                self, *, parent: str, query: str = ..., **kwargs: typing.Any
            ) -> CheckTransitiveMembershipResponseHttpRequest: ...
            def create(
                self, *, parent: str, body: Membership = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> MembershipHttpRequest: ...
            def getMembershipGraph(
                self, *, parent: str, query: str = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                view: typing_extensions.Literal["BASIC", "FULL"] = ...,
                **kwargs: typing.Any
            ) -> ListMembershipsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListMembershipsResponseHttpRequest,
                previous_response: ListMembershipsResponse,
            ) -> ListMembershipsResponseHttpRequest | None: ...
            def lookup(
                self,
                *,
                parent: str,
                memberKey_id: str = ...,
                memberKey_namespace: str = ...,
                **kwargs: typing.Any
            ) -> LookupMembershipNameResponseHttpRequest: ...
            def modifyMembershipRoles(
                self,
                *,
                name: str,
                body: ModifyMembershipRolesRequest = ...,
                **kwargs: typing.Any
            ) -> ModifyMembershipRolesResponseHttpRequest: ...
            def searchTransitiveGroups(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                query: str = ...,
                **kwargs: typing.Any
            ) -> SearchTransitiveGroupsResponseHttpRequest: ...
            def searchTransitiveGroups_next(
                self,
                previous_request: SearchTransitiveGroupsResponseHttpRequest,
                previous_response: SearchTransitiveGroupsResponse,
            ) -> SearchTransitiveGroupsResponseHttpRequest | None: ...
            def searchTransitiveMemberships(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> SearchTransitiveMembershipsResponseHttpRequest: ...
            def searchTransitiveMemberships_next(
                self,
                previous_request: SearchTransitiveMembershipsResponseHttpRequest,
                previous_response: SearchTransitiveMembershipsResponse,
            ) -> SearchTransitiveMembershipsResponseHttpRequest | None: ...

        def create(
            self,
            *,
            body: Group = ...,
            initialGroupConfig: typing_extensions.Literal[
                "INITIAL_GROUP_CONFIG_UNSPECIFIED", "WITH_INITIAL_OWNER", "EMPTY"
            ] = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def delete(
            self, *, name: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def get(self, *, name: str, **kwargs: typing.Any) -> GroupHttpRequest: ...
        def getSecuritySettings(
            self, *, name: str, readMask: str = ..., **kwargs: typing.Any
        ) -> SecuritySettingsHttpRequest: ...
        def list(
            self,
            *,
            pageSize: int = ...,
            pageToken: str = ...,
            parent: str = ...,
            view: typing_extensions.Literal["VIEW_UNSPECIFIED", "BASIC", "FULL"] = ...,
            **kwargs: typing.Any
        ) -> ListGroupsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListGroupsResponseHttpRequest,
            previous_response: ListGroupsResponse,
        ) -> ListGroupsResponseHttpRequest | None: ...
        def lookup(
            self,
            *,
            groupKey_id: str = ...,
            groupKey_namespace: str = ...,
            **kwargs: typing.Any
        ) -> LookupGroupNameResponseHttpRequest: ...
        def patch(
            self,
            *,
            name: str,
            body: Group = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def search(
            self,
            *,
            pageSize: int = ...,
            pageToken: str = ...,
            query: str = ...,
            view: typing_extensions.Literal["BASIC", "FULL"] = ...,
            **kwargs: typing.Any
        ) -> SearchGroupsResponseHttpRequest: ...
        def search_next(
            self,
            previous_request: SearchGroupsResponseHttpRequest,
            previous_response: SearchGroupsResponse,
        ) -> SearchGroupsResponseHttpRequest | None: ...
        def updateSecuritySettings(
            self,
            *,
            name: str,
            body: SecuritySettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def memberships(self) -> MembershipsResource: ...

    @typing.type_check_only
    class InboundSamlSsoProfilesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class IdpCredentialsResource(googleapiclient.discovery.Resource):
            def add(
                self,
                *,
                parent: str,
                body: AddIdpCredentialRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> IdpCredentialHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListIdpCredentialsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListIdpCredentialsResponseHttpRequest,
                previous_response: ListIdpCredentialsResponse,
            ) -> ListIdpCredentialsResponseHttpRequest | None: ...

        def create(
            self, *, body: InboundSamlSsoProfile = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def delete(
            self, *, name: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def get(
            self, *, name: str, **kwargs: typing.Any
        ) -> InboundSamlSsoProfileHttpRequest: ...
        def list(
            self,
            *,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListInboundSamlSsoProfilesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListInboundSamlSsoProfilesResponseHttpRequest,
            previous_response: ListInboundSamlSsoProfilesResponse,
        ) -> ListInboundSamlSsoProfilesResponseHttpRequest | None: ...
        def patch(
            self,
            *,
            name: str,
            body: InboundSamlSsoProfile = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def idpCredentials(self) -> IdpCredentialsResource: ...

    @typing.type_check_only
    class InboundSsoAssignmentsResource(googleapiclient.discovery.Resource):
        def create(
            self, *, body: InboundSsoAssignment = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def delete(
            self, *, name: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def get(
            self, *, name: str, **kwargs: typing.Any
        ) -> InboundSsoAssignmentHttpRequest: ...
        def list(
            self,
            *,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListInboundSsoAssignmentsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListInboundSsoAssignmentsResponseHttpRequest,
            previous_response: ListInboundSsoAssignmentsResponse,
        ) -> ListInboundSsoAssignmentsResponseHttpRequest | None: ...
        def patch(
            self,
            *,
            name: str,
            body: InboundSsoAssignment = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...

    @typing.type_check_only
    class OrgUnitsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class MembershipsResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                parent: str,
                customer: str = ...,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListOrgMembershipsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListOrgMembershipsResponseHttpRequest,
                previous_response: ListOrgMembershipsResponse,
            ) -> ListOrgMembershipsResponseHttpRequest | None: ...
            def move(
                self,
                *,
                name: str,
                body: MoveOrgMembershipRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        def memberships(self) -> MembershipsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def customers(self) -> CustomersResource: ...
    def devices(self) -> DevicesResource: ...
    def groups(self) -> GroupsResource: ...
    def inboundSamlSsoProfiles(self) -> InboundSamlSsoProfilesResource: ...
    def inboundSsoAssignments(self) -> InboundSsoAssignmentsResource: ...
    def orgUnits(self) -> OrgUnitsResource: ...

@typing.type_check_only
class CheckTransitiveMembershipResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CheckTransitiveMembershipResponse: ...

@typing.type_check_only
class ClientStateHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ClientState: ...

@typing.type_check_only
class DeviceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Device: ...

@typing.type_check_only
class DeviceUserHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DeviceUser: ...

@typing.type_check_only
class GroupHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Group: ...

@typing.type_check_only
class IdpCredentialHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> IdpCredential: ...

@typing.type_check_only
class InboundSamlSsoProfileHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> InboundSamlSsoProfile: ...

@typing.type_check_only
class InboundSsoAssignmentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> InboundSsoAssignment: ...

@typing.type_check_only
class IsInvitableUserResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> IsInvitableUserResponse: ...

@typing.type_check_only
class ListDeviceUsersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDeviceUsersResponse: ...

@typing.type_check_only
class ListDevicesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDevicesResponse: ...

@typing.type_check_only
class ListGroupsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGroupsResponse: ...

@typing.type_check_only
class ListIdpCredentialsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListIdpCredentialsResponse: ...

@typing.type_check_only
class ListInboundSamlSsoProfilesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListInboundSamlSsoProfilesResponse: ...

@typing.type_check_only
class ListInboundSsoAssignmentsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListInboundSsoAssignmentsResponse: ...

@typing.type_check_only
class ListMembershipsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListMembershipsResponse: ...

@typing.type_check_only
class ListOrgMembershipsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOrgMembershipsResponse: ...

@typing.type_check_only
class ListUserInvitationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListUserInvitationsResponse: ...

@typing.type_check_only
class LookupGroupNameResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LookupGroupNameResponse: ...

@typing.type_check_only
class LookupMembershipNameResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LookupMembershipNameResponse: ...

@typing.type_check_only
class LookupSelfDeviceUsersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LookupSelfDeviceUsersResponse: ...

@typing.type_check_only
class MembershipHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Membership: ...

@typing.type_check_only
class ModifyMembershipRolesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ModifyMembershipRolesResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class SearchGroupsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchGroupsResponse: ...

@typing.type_check_only
class SearchTransitiveGroupsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchTransitiveGroupsResponse: ...

@typing.type_check_only
class SearchTransitiveMembershipsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchTransitiveMembershipsResponse: ...

@typing.type_check_only
class SecuritySettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SecuritySettings: ...

@typing.type_check_only
class UserInvitationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UserInvitation: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AccessContextManagerOperationMetadata(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class AccessLevel(typing_extensions.TypedDict, total=False):
    basic: BasicLevel
    custom: CustomLevel
    description: str
    name: str
    title: str

@typing.type_check_only
class AccessPolicy(typing_extensions.TypedDict, total=False):
    name: str
    parent: str
    title: str

@typing.type_check_only
class BasicLevel(typing_extensions.TypedDict, total=False):
    combiningFunction: typing_extensions.Literal["AND", "OR"]
    conditions: _list[Condition]

@typing.type_check_only
class Condition(typing_extensions.TypedDict, total=False):
    devicePolicy: DevicePolicy
    ipSubnetworks: _list[str]
    members: _list[str]
    negate: bool
    regions: _list[str]
    requiredAccessLevels: _list[str]

@typing.type_check_only
class CustomLevel(typing_extensions.TypedDict, total=False):
    expr: Expr

@typing.type_check_only
class DevicePolicy(typing_extensions.TypedDict, total=False):
    allowedDeviceManagementLevels: _list[str]
    allowedEncryptionStatuses: _list[str]
    osConstraints: _list[OsConstraint]
    requireAdminApproval: bool
    requireCorpOwned: bool
    requireScreenlock: bool

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class ListAccessLevelsResponse(typing_extensions.TypedDict, total=False):
    accessLevels: _list[AccessLevel]
    nextPageToken: str

@typing.type_check_only
class ListAccessPoliciesResponse(typing_extensions.TypedDict, total=False):
    accessPolicies: _list[AccessPolicy]
    nextPageToken: str

@typing.type_check_only
class ListServicePerimetersResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    servicePerimeters: _list[ServicePerimeter]

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OsConstraint(typing_extensions.TypedDict, total=False):
    minimumVersion: str
    osType: typing_extensions.Literal[
        "OS_UNSPECIFIED",
        "DESKTOP_MAC",
        "DESKTOP_WINDOWS",
        "DESKTOP_LINUX",
        "DESKTOP_CHROME_OS",
        "ANDROID",
        "IOS",
    ]
    requireVerifiedChromeOs: bool

@typing.type_check_only
class ServicePerimeter(typing_extensions.TypedDict, total=False):
    description: str
    name: str
    perimeterType: typing_extensions.Literal[
        "PERIMETER_TYPE_REGULAR", "PERIMETER_TYPE_BRIDGE"
    ]
    status: ServicePerimeterConfig
    title: str

@typing.type_check_only
class ServicePerimeterConfig(typing_extensions.TypedDict, total=False):
    accessLevels: _list[str]
    resources: _list[str]
    restrictedServices: _list[str]
    unrestrictedServices: _list[str]
    vpcAccessibleServices: VpcAccessibleServices

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class VpcAccessibleServices(typing_extensions.TypedDict, total=False):
    allowedServices: _list[str]
    enableRestriction: bool



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class TasksResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class TasklistsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, tasklist: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, tasklist: str, **kwargs: typing.Any
        ) -> TaskListHttpRequest: ...
        def insert(
            self, *, body: TaskList = ..., **kwargs: typing.Any
        ) -> TaskListHttpRequest: ...
        def list(
            self, *, maxResults: int = ..., pageToken: str = ..., **kwargs: typing.Any
        ) -> TaskListsHttpRequest: ...
        def list_next(
            self, previous_request: TaskListsHttpRequest, previous_response: TaskLists
        ) -> TaskListsHttpRequest | None: ...
        def patch(
            self, *, tasklist: str, body: TaskList = ..., **kwargs: typing.Any
        ) -> TaskListHttpRequest: ...
        def update(
            self, *, tasklist: str, body: TaskList = ..., **kwargs: typing.Any
        ) -> TaskListHttpRequest: ...

    @typing.type_check_only
    class TasksResource(googleapiclient.discovery.Resource):
        def clear(
            self, *, tasklist: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def delete(
            self, *, tasklist: str, task: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, tasklist: str, task: str, **kwargs: typing.Any
        ) -> TaskHttpRequest: ...
        def insert(
            self,
            *,
            tasklist: str,
            body: Task = ...,
            parent: str = ...,
            previous: str = ...,
            **kwargs: typing.Any
        ) -> TaskHttpRequest: ...
        def list(
            self,
            *,
            tasklist: str,
            completedMax: str = ...,
            completedMin: str = ...,
            dueMax: str = ...,
            dueMin: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            showCompleted: bool = ...,
            showDeleted: bool = ...,
            showHidden: bool = ...,
            updatedMin: str = ...,
            **kwargs: typing.Any
        ) -> TasksHttpRequest: ...
        def list_next(
            self, previous_request: TasksHttpRequest, previous_response: Tasks
        ) -> TasksHttpRequest | None: ...
        def move(
            self,
            *,
            tasklist: str,
            task: str,
            parent: str = ...,
            previous: str = ...,
            **kwargs: typing.Any
        ) -> TaskHttpRequest: ...
        def patch(
            self, *, tasklist: str, task: str, body: Task = ..., **kwargs: typing.Any
        ) -> TaskHttpRequest: ...
        def update(
            self, *, tasklist: str, task: str, body: Task = ..., **kwargs: typing.Any
        ) -> TaskHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def tasklists(self) -> TasklistsResource: ...
    def tasks(self) -> TasksResource: ...

@typing.type_check_only
class TaskHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Task: ...

@typing.type_check_only
class TaskListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TaskList: ...

@typing.type_check_only
class TaskListsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TaskLists: ...

@typing.type_check_only
class TasksHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Tasks: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class FormsResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class FormsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ResponsesResource(googleapiclient.discovery.Resource):
            def get(
                self, *, formId: str, responseId: str, **kwargs: typing.Any
            ) -> FormResponseHttpRequest: ...
            def list(
                self,
                *,
                formId: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListFormResponsesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListFormResponsesResponseHttpRequest,
                previous_response: ListFormResponsesResponse,
            ) -> ListFormResponsesResponseHttpRequest | None: ...

        @typing.type_check_only
        class WatchesResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                formId: str,
                body: CreateWatchRequest = ...,
                **kwargs: typing.Any
            ) -> WatchHttpRequest: ...
            def delete(
                self, *, formId: str, watchId: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def list(
                self, *, formId: str, **kwargs: typing.Any
            ) -> ListWatchesResponseHttpRequest: ...
            def renew(
                self,
                *,
                formId: str,
                watchId: str,
                body: RenewWatchRequest = ...,
                **kwargs: typing.Any
            ) -> WatchHttpRequest: ...

        def batchUpdate(
            self,
            *,
            formId: str,
            body: BatchUpdateFormRequest = ...,
            **kwargs: typing.Any
        ) -> BatchUpdateFormResponseHttpRequest: ...
        def create(
            self, *, body: Form = ..., **kwargs: typing.Any
        ) -> FormHttpRequest: ...
        def get(self, *, formId: str, **kwargs: typing.Any) -> FormHttpRequest: ...
        def responses(self) -> ResponsesResource: ...
        def watches(self) -> WatchesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def forms(self) -> FormsResource: ...

@typing.type_check_only
class BatchUpdateFormResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchUpdateFormResponse: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class FormHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Form: ...

@typing.type_check_only
class FormResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> FormResponse: ...

@typing.type_check_only
class ListFormResponsesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListFormResponsesResponse: ...

@typing.type_check_only
class ListWatchesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListWatchesResponse: ...

@typing.type_check_only
class WatchHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Watch: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class PlatformSummary(typing_extensions.TypedDict, total=False):
    betterAdsStatus: typing_extensions.Literal[
        "UNKNOWN", "PASSING", "WARNING", "FAILING"
    ]
    enforcementTime: str
    filterStatus: typing_extensions.Literal["UNKNOWN", "ON", "OFF", "PAUSED", "PENDING"]
    lastChangeTime: str
    region: _list[str]
    reportUrl: str
    underReview: bool

@typing.type_check_only
class SiteSummaryResponse(typing_extensions.TypedDict, total=False):
    desktopSummary: PlatformSummary
    mobileSummary: PlatformSummary
    reviewedSite: str

@typing.type_check_only
class ViolatingSitesResponse(typing_extensions.TypedDict, total=False):
    violatingSites: _list[SiteSummaryResponse]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class ListReposResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    repos: _list[Repo]

@typing.type_check_only
class MirrorConfig(typing_extensions.TypedDict, total=False):
    deployKeyId: str
    url: str
    webhookId: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class ProjectConfig(typing_extensions.TypedDict, total=False):
    enablePrivateKeyCheck: bool
    name: str
    pubsubConfigs: dict[str, typing.Any]

@typing.type_check_only
class PubsubConfig(typing_extensions.TypedDict, total=False):
    messageFormat: typing_extensions.Literal[
        "MESSAGE_FORMAT_UNSPECIFIED", "PROTOBUF", "JSON"
    ]
    serviceAccountEmail: str
    topic: str

@typing.type_check_only
class Repo(typing_extensions.TypedDict, total=False):
    mirrorConfig: MirrorConfig
    name: str
    pubsubConfigs: dict[str, typing.Any]
    size: str
    url: str

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy
    updateMask: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class SyncRepoMetadata(typing_extensions.TypedDict, total=False):
    name: str
    startTime: str
    statusMessage: str
    updateTime: str

@typing.type_check_only
class SyncRepoRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class UpdateProjectConfigRequest(typing_extensions.TypedDict, total=False):
    projectConfig: ProjectConfig
    updateMask: str

@typing.type_check_only
class UpdateRepoRequest(typing_extensions.TypedDict, total=False):
    repo: Repo
    updateMask: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Aggregation(typing_extensions.TypedDict, total=False):
    alignmentPeriod: str
    crossSeriesReducer: typing_extensions.Literal[
        "REDUCE_NONE",
        "REDUCE_MEAN",
        "REDUCE_MIN",
        "REDUCE_MAX",
        "REDUCE_SUM",
        "REDUCE_STDDEV",
        "REDUCE_COUNT",
        "REDUCE_COUNT_TRUE",
        "REDUCE_COUNT_FALSE",
        "REDUCE_FRACTION_TRUE",
        "REDUCE_PERCENTILE_99",
        "REDUCE_PERCENTILE_95",
        "REDUCE_PERCENTILE_50",
        "REDUCE_PERCENTILE_05",
    ]
    groupByFields: _list[str]
    perSeriesAligner: typing_extensions.Literal[
        "ALIGN_NONE",
        "ALIGN_DELTA",
        "ALIGN_RATE",
        "ALIGN_INTERPOLATE",
        "ALIGN_NEXT_OLDER",
        "ALIGN_MIN",
        "ALIGN_MAX",
        "ALIGN_MEAN",
        "ALIGN_COUNT",
        "ALIGN_SUM",
        "ALIGN_STDDEV",
        "ALIGN_COUNT_TRUE",
        "ALIGN_COUNT_FALSE",
        "ALIGN_FRACTION_TRUE",
        "ALIGN_PERCENTILE_99",
        "ALIGN_PERCENTILE_95",
        "ALIGN_PERCENTILE_50",
        "ALIGN_PERCENTILE_05",
        "ALIGN_PERCENT_CHANGE",
    ]

@typing.type_check_only
class AlertPolicy(typing_extensions.TypedDict, total=False):
    alertStrategy: AlertStrategy
    combiner: typing_extensions.Literal[
        "COMBINE_UNSPECIFIED", "AND", "OR", "AND_WITH_MATCHING_RESOURCE"
    ]
    conditions: _list[Condition]
    creationRecord: MutationRecord
    displayName: str
    documentation: Documentation
    enabled: bool
    mutationRecord: MutationRecord
    name: str
    notificationChannels: _list[str]
    userLabels: dict[str, typing.Any]
    validity: Status

@typing.type_check_only
class AlertStrategy(typing_extensions.TypedDict, total=False):
    autoClose: str
    notificationRateLimit: NotificationRateLimit

@typing.type_check_only
class AppEngine(typing_extensions.TypedDict, total=False):
    moduleId: str

@typing.type_check_only
class AvailabilityCriteria(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class BasicAuthentication(typing_extensions.TypedDict, total=False):
    password: str
    username: str

@typing.type_check_only
class BasicService(typing_extensions.TypedDict, total=False):
    serviceLabels: dict[str, typing.Any]
    serviceType: str

@typing.type_check_only
class BasicSli(typing_extensions.TypedDict, total=False):
    availability: AvailabilityCriteria
    latency: LatencyCriteria
    location: _list[str]
    method: _list[str]
    version: _list[str]

@typing.type_check_only
class BucketOptions(typing_extensions.TypedDict, total=False):
    explicitBuckets: Explicit
    exponentialBuckets: Exponential
    linearBuckets: Linear

@typing.type_check_only
class CloudEndpoints(typing_extensions.TypedDict, total=False):
    service: str

@typing.type_check_only
class CloudRun(typing_extensions.TypedDict, total=False):
    location: str
    serviceName: str

@typing.type_check_only
class ClusterIstio(typing_extensions.TypedDict, total=False):
    clusterName: str
    location: str
    serviceName: str
    serviceNamespace: str

@typing.type_check_only
class CollectdPayload(typing_extensions.TypedDict, total=False):
    endTime: str
    metadata: dict[str, typing.Any]
    plugin: str
    pluginInstance: str
    startTime: str
    type: str
    typeInstance: str
    values: _list[CollectdValue]

@typing.type_check_only
class CollectdPayloadError(typing_extensions.TypedDict, total=False):
    error: Status
    index: int
    valueErrors: _list[CollectdValueError]

@typing.type_check_only
class CollectdValue(typing_extensions.TypedDict, total=False):
    dataSourceName: str
    dataSourceType: typing_extensions.Literal[
        "UNSPECIFIED_DATA_SOURCE_TYPE", "GAUGE", "COUNTER", "DERIVE", "ABSOLUTE"
    ]
    value: TypedValue

@typing.type_check_only
class CollectdValueError(typing_extensions.TypedDict, total=False):
    error: Status
    index: int

@typing.type_check_only
class Condition(typing_extensions.TypedDict, total=False):
    conditionAbsent: MetricAbsence
    conditionMatchedLog: LogMatch
    conditionMonitoringQueryLanguage: MonitoringQueryLanguageCondition
    conditionThreshold: MetricThreshold
    displayName: str
    name: str

@typing.type_check_only
class ContentMatcher(typing_extensions.TypedDict, total=False):
    content: str
    jsonPathMatcher: JsonPathMatcher
    matcher: typing_extensions.Literal[
        "CONTENT_MATCHER_OPTION_UNSPECIFIED",
        "CONTAINS_STRING",
        "NOT_CONTAINS_STRING",
        "MATCHES_REGEX",
        "NOT_MATCHES_REGEX",
        "MATCHES_JSON_PATH",
        "NOT_MATCHES_JSON_PATH",
    ]

@typing.type_check_only
class CreateCollectdTimeSeriesRequest(typing_extensions.TypedDict, total=False):
    collectdPayloads: _list[CollectdPayload]
    collectdVersion: str
    resource: MonitoredResource

@typing.type_check_only
class CreateCollectdTimeSeriesResponse(typing_extensions.TypedDict, total=False):
    payloadErrors: _list[CollectdPayloadError]
    summary: CreateTimeSeriesSummary

@typing.type_check_only
class CreateTimeSeriesRequest(typing_extensions.TypedDict, total=False):
    timeSeries: _list[TimeSeries]

@typing.type_check_only
class CreateTimeSeriesSummary(typing_extensions.TypedDict, total=False):
    errors: _list[Error]
    successPointCount: int
    totalPointCount: int

@typing.type_check_only
class Custom(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Distribution(typing_extensions.TypedDict, total=False):
    bucketCounts: _list[str]
    bucketOptions: BucketOptions
    count: str
    exemplars: _list[Exemplar]
    mean: float
    range: Range
    sumOfSquaredDeviation: float

@typing.type_check_only
class DistributionCut(typing_extensions.TypedDict, total=False):
    distributionFilter: str
    range: GoogleMonitoringV3Range

@typing.type_check_only
class Documentation(typing_extensions.TypedDict, total=False):
    content: str
    mimeType: str

@typing.type_check_only
class DroppedLabels(typing_extensions.TypedDict, total=False):
    label: dict[str, typing.Any]

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Error(typing_extensions.TypedDict, total=False):
    pointCount: int
    status: Status

@typing.type_check_only
class Exemplar(typing_extensions.TypedDict, total=False):
    attachments: _list[dict[str, typing.Any]]
    timestamp: str
    value: float

@typing.type_check_only
class Explicit(typing_extensions.TypedDict, total=False):
    bounds: _list[float]

@typing.type_check_only
class Exponential(typing_extensions.TypedDict, total=False):
    growthFactor: float
    numFiniteBuckets: int
    scale: float

@typing.type_check_only
class Field(typing_extensions.TypedDict, total=False):
    cardinality: typing_extensions.Literal[
        "CARDINALITY_UNKNOWN",
        "CARDINALITY_OPTIONAL",
        "CARDINALITY_REQUIRED",
        "CARDINALITY_REPEATED",
    ]
    defaultValue: str
    jsonName: str
    kind: typing_extensions.Literal[
        "TYPE_UNKNOWN",
        "TYPE_DOUBLE",
        "TYPE_FLOAT",
        "TYPE_INT64",
        "TYPE_UINT64",
        "TYPE_INT32",
        "TYPE_FIXED64",
        "TYPE_FIXED32",
        "TYPE_BOOL",
        "TYPE_STRING",
        "TYPE_GROUP",
        "TYPE_MESSAGE",
        "TYPE_BYTES",
        "TYPE_UINT32",
        "TYPE_ENUM",
        "TYPE_SFIXED32",
        "TYPE_SFIXED64",
        "TYPE_SINT32",
        "TYPE_SINT64",
    ]
    name: str
    number: int
    oneofIndex: int
    options: _list[Option]
    packed: bool
    typeUrl: str

@typing.type_check_only
class GetNotificationChannelVerificationCodeRequest(
    typing_extensions.TypedDict, total=False
):
    expireTime: str

@typing.type_check_only
class GetNotificationChannelVerificationCodeResponse(
    typing_extensions.TypedDict, total=False
):
    code: str
    expireTime: str

@typing.type_check_only
class GkeNamespace(typing_extensions.TypedDict, total=False):
    clusterName: str
    location: str
    namespaceName: str
    projectId: str

@typing.type_check_only
class GkeService(typing_extensions.TypedDict, total=False):
    clusterName: str
    location: str
    namespaceName: str
    projectId: str
    serviceName: str

@typing.type_check_only
class GkeWorkload(typing_extensions.TypedDict, total=False):
    clusterName: str
    location: str
    namespaceName: str
    projectId: str
    topLevelControllerName: str
    topLevelControllerType: str

@typing.type_check_only
class GoogleMonitoringV3Range(typing_extensions.TypedDict, total=False):
    max: float
    min: float

@typing.type_check_only
class Group(typing_extensions.TypedDict, total=False):
    displayName: str
    filter: str
    isCluster: bool
    name: str
    parentName: str

@typing.type_check_only
class HttpCheck(typing_extensions.TypedDict, total=False):
    acceptedResponseStatusCodes: _list[ResponseStatusCode]
    authInfo: BasicAuthentication
    body: str
    contentType: typing_extensions.Literal["TYPE_UNSPECIFIED", "URL_ENCODED"]
    headers: dict[str, typing.Any]
    maskHeaders: bool
    path: str
    pingConfig: PingConfig
    port: int
    requestMethod: typing_extensions.Literal["METHOD_UNSPECIFIED", "GET", "POST"]
    useSsl: bool
    validateSsl: bool

@typing.type_check_only
class InternalChecker(typing_extensions.TypedDict, total=False):
    displayName: str
    gcpZone: str
    name: str
    network: str
    peerProjectId: str
    state: typing_extensions.Literal["UNSPECIFIED", "CREATING", "RUNNING"]

@typing.type_check_only
class IstioCanonicalService(typing_extensions.TypedDict, total=False):
    canonicalService: str
    canonicalServiceNamespace: str
    meshUid: str

@typing.type_check_only
class JsonPathMatcher(typing_extensions.TypedDict, total=False):
    jsonMatcher: typing_extensions.Literal[
        "JSON_PATH_MATCHER_OPTION_UNSPECIFIED", "EXACT_MATCH", "REGEX_MATCH"
    ]
    jsonPath: str

@typing.type_check_only
class LabelDescriptor(typing_extensions.TypedDict, total=False):
    description: str
    key: str
    valueType: typing_extensions.Literal["STRING", "BOOL", "INT64"]

@typing.type_check_only
class LabelValue(typing_extensions.TypedDict, total=False):
    boolValue: bool
    int64Value: str
    stringValue: str

@typing.type_check_only
class LatencyCriteria(typing_extensions.TypedDict, total=False):
    threshold: str

@typing.type_check_only
class Linear(typing_extensions.TypedDict, total=False):
    numFiniteBuckets: int
    offset: float
    width: float

@typing.type_check_only
class ListAlertPoliciesResponse(typing_extensions.TypedDict, total=False):
    alertPolicies: _list[AlertPolicy]
    nextPageToken: str
    totalSize: int

@typing.type_check_only
class ListGroupMembersResponse(typing_extensions.TypedDict, total=False):
    members: _list[MonitoredResource]
    nextPageToken: str
    totalSize: int

@typing.type_check_only
class ListGroupsResponse(typing_extensions.TypedDict, total=False):
    group: _list[Group]
    nextPageToken: str

@typing.type_check_only
class ListMetricDescriptorsResponse(typing_extensions.TypedDict, total=False):
    metricDescriptors: _list[MetricDescriptor]
    nextPageToken: str

@typing.type_check_only
class ListMonitoredResourceDescriptorsResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    resourceDescriptors: _list[MonitoredResourceDescriptor]

@typing.type_check_only
class ListNotificationChannelDescriptorsResponse(
    typing_extensions.TypedDict, total=False
):
    channelDescriptors: _list[NotificationChannelDescriptor]
    nextPageToken: str

@typing.type_check_only
class ListNotificationChannelsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    notificationChannels: _list[NotificationChannel]
    totalSize: int

@typing.type_check_only
class ListServiceLevelObjectivesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    serviceLevelObjectives: _list[ServiceLevelObjective]

@typing.type_check_only
class ListServicesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    services: _list[Service]

@typing.type_check_only
class ListTimeSeriesResponse(typing_extensions.TypedDict, total=False):
    executionErrors: _list[Status]
    nextPageToken: str
    timeSeries: _list[TimeSeries]
    unit: str

@typing.type_check_only
class ListUptimeCheckConfigsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    totalSize: int
    uptimeCheckConfigs: _list[UptimeCheckConfig]

@typing.type_check_only
class ListUptimeCheckIpsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    uptimeCheckIps: _list[UptimeCheckIp]

@typing.type_check_only
class LogMatch(typing_extensions.TypedDict, total=False):
    filter: str
    labelExtractors: dict[str, typing.Any]

@typing.type_check_only
class MeshIstio(typing_extensions.TypedDict, total=False):
    meshUid: str
    serviceName: str
    serviceNamespace: str

@typing.type_check_only
class Metric(typing_extensions.TypedDict, total=False):
    labels: dict[str, typing.Any]
    type: str

@typing.type_check_only
class MetricAbsence(typing_extensions.TypedDict, total=False):
    aggregations: _list[Aggregation]
    duration: str
    filter: str
    trigger: Trigger

@typing.type_check_only
class MetricDescriptor(typing_extensions.TypedDict, total=False):
    description: str
    displayName: str
    labels: _list[LabelDescriptor]
    launchStage: typing_extensions.Literal[
        "LAUNCH_STAGE_UNSPECIFIED",
        "UNIMPLEMENTED",
        "PRELAUNCH",
        "EARLY_ACCESS",
        "ALPHA",
        "BETA",
        "GA",
        "DEPRECATED",
    ]
    metadata: MetricDescriptorMetadata
    metricKind: typing_extensions.Literal[
        "METRIC_KIND_UNSPECIFIED", "GAUGE", "DELTA", "CUMULATIVE"
    ]
    monitoredResourceTypes: _list[str]
    name: str
    type: str
    unit: str
    valueType: typing_extensions.Literal[
        "VALUE_TYPE_UNSPECIFIED",
        "BOOL",
        "INT64",
        "DOUBLE",
        "STRING",
        "DISTRIBUTION",
        "MONEY",
    ]

@typing.type_check_only
class MetricDescriptorMetadata(typing_extensions.TypedDict, total=False):
    ingestDelay: str
    launchStage: typing_extensions.Literal[
        "LAUNCH_STAGE_UNSPECIFIED",
        "UNIMPLEMENTED",
        "PRELAUNCH",
        "EARLY_ACCESS",
        "ALPHA",
        "BETA",
        "GA",
        "DEPRECATED",
    ]
    samplePeriod: str

@typing.type_check_only
class MetricRange(typing_extensions.TypedDict, total=False):
    range: GoogleMonitoringV3Range
    timeSeries: str

@typing.type_check_only
class MetricThreshold(typing_extensions.TypedDict, total=False):
    aggregations: _list[Aggregation]
    comparison: typing_extensions.Literal[
        "COMPARISON_UNSPECIFIED",
        "COMPARISON_GT",
        "COMPARISON_GE",
        "COMPARISON_LT",
        "COMPARISON_LE",
        "COMPARISON_EQ",
        "COMPARISON_NE",
    ]
    denominatorAggregations: _list[Aggregation]
    denominatorFilter: str
    duration: str
    evaluationMissingData: typing_extensions.Literal[
        "EVALUATION_MISSING_DATA_UNSPECIFIED",
        "EVALUATION_MISSING_DATA_INACTIVE",
        "EVALUATION_MISSING_DATA_ACTIVE",
        "EVALUATION_MISSING_DATA_NO_OP",
    ]
    filter: str
    thresholdValue: float
    trigger: Trigger

@typing.type_check_only
class MonitoredResource(typing_extensions.TypedDict, total=False):
    labels: dict[str, typing.Any]
    type: str

@typing.type_check_only
class MonitoredResourceDescriptor(typing_extensions.TypedDict, total=False):
    description: str
    displayName: str
    labels: _list[LabelDescriptor]
    launchStage: typing_extensions.Literal[
        "LAUNCH_STAGE_UNSPECIFIED",
        "UNIMPLEMENTED",
        "PRELAUNCH",
        "EARLY_ACCESS",
        "ALPHA",
        "BETA",
        "GA",
        "DEPRECATED",
    ]
    name: str
    type: str

@typing.type_check_only
class MonitoredResourceMetadata(typing_extensions.TypedDict, total=False):
    systemLabels: dict[str, typing.Any]
    userLabels: dict[str, typing.Any]

@typing.type_check_only
class MonitoringQueryLanguageCondition(typing_extensions.TypedDict, total=False):
    duration: str
    evaluationMissingData: typing_extensions.Literal[
        "EVALUATION_MISSING_DATA_UNSPECIFIED",
        "EVALUATION_MISSING_DATA_INACTIVE",
        "EVALUATION_MISSING_DATA_ACTIVE",
        "EVALUATION_MISSING_DATA_NO_OP",
    ]
    query: str
    trigger: Trigger

@typing.type_check_only
class MutationRecord(typing_extensions.TypedDict, total=False):
    mutateTime: str
    mutatedBy: str

@typing.type_check_only
class NotificationChannel(typing_extensions.TypedDict, total=False):
    creationRecord: MutationRecord
    description: str
    displayName: str
    enabled: bool
    labels: dict[str, typing.Any]
    mutationRecords: _list[MutationRecord]
    name: str
    type: str
    userLabels: dict[str, typing.Any]
    verificationStatus: typing_extensions.Literal[
        "VERIFICATION_STATUS_UNSPECIFIED", "UNVERIFIED", "VERIFIED"
    ]

@typing.type_check_only
class NotificationChannelDescriptor(typing_extensions.TypedDict, total=False):
    description: str
    displayName: str
    labels: _list[LabelDescriptor]
    launchStage: typing_extensions.Literal[
        "LAUNCH_STAGE_UNSPECIFIED",
        "UNIMPLEMENTED",
        "PRELAUNCH",
        "EARLY_ACCESS",
        "ALPHA",
        "BETA",
        "GA",
        "DEPRECATED",
    ]
    name: str
    supportedTiers: _list[str]
    type: str

@typing.type_check_only
class NotificationRateLimit(typing_extensions.TypedDict, total=False):
    period: str

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    createTime: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "CREATED", "RUNNING", "DONE", "CANCELLED"
    ]
    updateTime: str

@typing.type_check_only
class Option(typing_extensions.TypedDict, total=False):
    name: str
    value: dict[str, typing.Any]

@typing.type_check_only
class PerformanceThreshold(typing_extensions.TypedDict, total=False):
    basicSliPerformance: BasicSli
    performance: RequestBasedSli
    threshold: float

@typing.type_check_only
class PingConfig(typing_extensions.TypedDict, total=False):
    pingsCount: int

@typing.type_check_only
class Point(typing_extensions.TypedDict, total=False):
    interval: TimeInterval
    value: TypedValue

@typing.type_check_only
class PointData(typing_extensions.TypedDict, total=False):
    timeInterval: TimeInterval
    values: _list[TypedValue]

@typing.type_check_only
class QueryTimeSeriesRequest(typing_extensions.TypedDict, total=False):
    pageSize: int
    pageToken: str
    query: str

@typing.type_check_only
class QueryTimeSeriesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    partialErrors: _list[Status]
    timeSeriesData: _list[TimeSeriesData]
    timeSeriesDescriptor: TimeSeriesDescriptor

@typing.type_check_only
class Range(typing_extensions.TypedDict, total=False):
    max: float
    min: float

@typing.type_check_only
class RequestBasedSli(typing_extensions.TypedDict, total=False):
    distributionCut: DistributionCut
    goodTotalRatio: TimeSeriesRatio

@typing.type_check_only
class ResourceGroup(typing_extensions.TypedDict, total=False):
    groupId: str
    resourceType: typing_extensions.Literal[
        "RESOURCE_TYPE_UNSPECIFIED", "INSTANCE", "AWS_ELB_LOAD_BALANCER"
    ]

@typing.type_check_only
class ResponseStatusCode(typing_extensions.TypedDict, total=False):
    statusClass: typing_extensions.Literal[
        "STATUS_CLASS_UNSPECIFIED",
        "STATUS_CLASS_1XX",
        "STATUS_CLASS_2XX",
        "STATUS_CLASS_3XX",
        "STATUS_CLASS_4XX",
        "STATUS_CLASS_5XX",
        "STATUS_CLASS_ANY",
    ]
    statusValue: int

@typing.type_check_only
class SendNotificationChannelVerificationCodeRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class Service(typing_extensions.TypedDict, total=False):
    appEngine: AppEngine
    basicService: BasicService
    cloudEndpoints: CloudEndpoints
    cloudRun: CloudRun
    clusterIstio: ClusterIstio
    custom: Custom
    displayName: str
    gkeNamespace: GkeNamespace
    gkeService: GkeService
    gkeWorkload: GkeWorkload
    istioCanonicalService: IstioCanonicalService
    meshIstio: MeshIstio
    name: str
    telemetry: Telemetry
    userLabels: dict[str, typing.Any]

@typing.type_check_only
class ServiceLevelIndicator(typing_extensions.TypedDict, total=False):
    basicSli: BasicSli
    requestBased: RequestBasedSli
    windowsBased: WindowsBasedSli

@typing.type_check_only
class ServiceLevelObjective(typing_extensions.TypedDict, total=False):
    calendarPeriod: typing_extensions.Literal[
        "CALENDAR_PERIOD_UNSPECIFIED",
        "DAY",
        "WEEK",
        "FORTNIGHT",
        "MONTH",
        "QUARTER",
        "HALF",
        "YEAR",
    ]
    displayName: str
    goal: float
    name: str
    rollingPeriod: str
    serviceLevelIndicator: ServiceLevelIndicator
    userLabels: dict[str, typing.Any]

@typing.type_check_only
class SourceContext(typing_extensions.TypedDict, total=False):
    fileName: str

@typing.type_check_only
class SpanContext(typing_extensions.TypedDict, total=False):
    spanName: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TcpCheck(typing_extensions.TypedDict, total=False):
    pingConfig: PingConfig
    port: int

@typing.type_check_only
class Telemetry(typing_extensions.TypedDict, total=False):
    resourceName: str

@typing.type_check_only
class TimeInterval(typing_extensions.TypedDict, total=False):
    endTime: str
    startTime: str

@typing.type_check_only
class TimeSeries(typing_extensions.TypedDict, total=False):
    metadata: MonitoredResourceMetadata
    metric: Metric
    metricKind: typing_extensions.Literal[
        "METRIC_KIND_UNSPECIFIED", "GAUGE", "DELTA", "CUMULATIVE"
    ]
    points: _list[Point]
    resource: MonitoredResource
    unit: str
    valueType: typing_extensions.Literal[
        "VALUE_TYPE_UNSPECIFIED",
        "BOOL",
        "INT64",
        "DOUBLE",
        "STRING",
        "DISTRIBUTION",
        "MONEY",
    ]

@typing.type_check_only
class TimeSeriesData(typing_extensions.TypedDict, total=False):
    labelValues: _list[LabelValue]
    pointData: _list[PointData]

@typing.type_check_only
class TimeSeriesDescriptor(typing_extensions.TypedDict, total=False):
    labelDescriptors: _list[LabelDescriptor]
    pointDescriptors: _list[ValueDescriptor]

@typing.type_check_only
class TimeSeriesRatio(typing_extensions.TypedDict, total=False):
    badServiceFilter: str
    goodServiceFilter: str
    totalServiceFilter: str

@typing.type_check_only
class Trigger(typing_extensions.TypedDict, total=False):
    count: int
    percent: float

@typing.type_check_only
class Type(typing_extensions.TypedDict, total=False):
    fields: _list[Field]
    name: str
    oneofs: _list[str]
    options: _list[Option]
    sourceContext: SourceContext
    syntax: typing_extensions.Literal["SYNTAX_PROTO2", "SYNTAX_PROTO3"]

@typing.type_check_only
class TypedValue(typing_extensions.TypedDict, total=False):
    boolValue: bool
    distributionValue: Distribution
    doubleValue: float
    int64Value: str
    stringValue: str

@typing.type_check_only
class UptimeCheckConfig(typing_extensions.TypedDict, total=False):
    checkerType: typing_extensions.Literal[
        "CHECKER_TYPE_UNSPECIFIED", "STATIC_IP_CHECKERS", "VPC_CHECKERS"
    ]
    contentMatchers: _list[ContentMatcher]
    displayName: str
    httpCheck: HttpCheck
    internalCheckers: _list[InternalChecker]
    isInternal: bool
    monitoredResource: MonitoredResource
    name: str
    period: str
    resourceGroup: ResourceGroup
    selectedRegions: _list[str]
    tcpCheck: TcpCheck
    timeout: str
    userLabels: dict[str, typing.Any]

@typing.type_check_only
class UptimeCheckIp(typing_extensions.TypedDict, total=False):
    ipAddress: str
    location: str
    region: typing_extensions.Literal[
        "REGION_UNSPECIFIED", "USA", "EUROPE", "SOUTH_AMERICA", "ASIA_PACIFIC"
    ]

@typing.type_check_only
class ValueDescriptor(typing_extensions.TypedDict, total=False):
    key: str
    metricKind: typing_extensions.Literal[
        "METRIC_KIND_UNSPECIFIED", "GAUGE", "DELTA", "CUMULATIVE"
    ]
    unit: str
    valueType: typing_extensions.Literal[
        "VALUE_TYPE_UNSPECIFIED",
        "BOOL",
        "INT64",
        "DOUBLE",
        "STRING",
        "DISTRIBUTION",
        "MONEY",
    ]

@typing.type_check_only
class VerifyNotificationChannelRequest(typing_extensions.TypedDict, total=False):
    code: str

@typing.type_check_only
class WindowsBasedSli(typing_extensions.TypedDict, total=False):
    goodBadMetricFilter: str
    goodTotalRatioThreshold: PerformanceThreshold
    metricMeanInRange: MetricRange
    metricSumInRange: MetricRange
    windowPeriod: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AcquisitionTargetingRule(typing_extensions.TypedDict, total=False):
    scope: TargetingRuleScope

@typing.type_check_only
class ActivateBasePlanRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ActivateSubscriptionOfferRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Apk(typing_extensions.TypedDict, total=False):
    binary: ApkBinary
    versionCode: int

@typing.type_check_only
class ApkBinary(typing_extensions.TypedDict, total=False):
    sha1: str
    sha256: str

@typing.type_check_only
class ApksAddExternallyHostedRequest(typing_extensions.TypedDict, total=False):
    externallyHostedApk: ExternallyHostedApk

@typing.type_check_only
class ApksAddExternallyHostedResponse(typing_extensions.TypedDict, total=False):
    externallyHostedApk: ExternallyHostedApk

@typing.type_check_only
class ApksListResponse(typing_extensions.TypedDict, total=False):
    apks: _list[Apk]
    kind: str

@typing.type_check_only
class AppDetails(typing_extensions.TypedDict, total=False):
    contactEmail: str
    contactPhone: str
    contactWebsite: str
    defaultLanguage: str

@typing.type_check_only
class AppEdit(typing_extensions.TypedDict, total=False):
    expiryTimeSeconds: str
    id: str

@typing.type_check_only
class ArchiveSubscriptionRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class AutoRenewingBasePlanType(typing_extensions.TypedDict, total=False):
    billingPeriodDuration: str
    gracePeriodDuration: str
    legacyCompatible: bool
    legacyCompatibleSubscriptionOfferId: str
    prorationMode: typing_extensions.Literal[
        "SUBSCRIPTION_PRORATION_MODE_UNSPECIFIED",
        "SUBSCRIPTION_PRORATION_MODE_CHARGE_ON_NEXT_BILLING_DATE",
        "SUBSCRIPTION_PRORATION_MODE_CHARGE_FULL_PRICE_IMMEDIATELY",
    ]
    resubscribeState: typing_extensions.Literal[
        "RESUBSCRIBE_STATE_UNSPECIFIED",
        "RESUBSCRIBE_STATE_ACTIVE",
        "RESUBSCRIBE_STATE_INACTIVE",
    ]

@typing.type_check_only
class AutoRenewingPlan(typing_extensions.TypedDict, total=False):
    autoRenewEnabled: bool

@typing.type_check_only
class BasePlan(typing_extensions.TypedDict, total=False):
    autoRenewingBasePlanType: AutoRenewingBasePlanType
    basePlanId: str
    offerTags: _list[OfferTag]
    otherRegionsConfig: OtherRegionsBasePlanConfig
    prepaidBasePlanType: PrepaidBasePlanType
    regionalConfigs: _list[RegionalBasePlanConfig]
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "DRAFT", "ACTIVE", "INACTIVE"]

@typing.type_check_only
class Bundle(typing_extensions.TypedDict, total=False):
    sha1: str
    sha256: str
    versionCode: int

@typing.type_check_only
class BundlesListResponse(typing_extensions.TypedDict, total=False):
    bundles: _list[Bundle]
    kind: str

@typing.type_check_only
class CancelSurveyResult(typing_extensions.TypedDict, total=False):
    reason: typing_extensions.Literal[
        "CANCEL_SURVEY_REASON_UNSPECIFIED",
        "CANCEL_SURVEY_REASON_NOT_ENOUGH_USAGE",
        "CANCEL_SURVEY_REASON_TECHNICAL_ISSUES",
        "CANCEL_SURVEY_REASON_COST_RELATED",
        "CANCEL_SURVEY_REASON_FOUND_BETTER_APP",
        "CANCEL_SURVEY_REASON_OTHERS",
    ]
    reasonUserInput: str

@typing.type_check_only
class CanceledStateContext(typing_extensions.TypedDict, total=False):
    developerInitiatedCancellation: DeveloperInitiatedCancellation
    replacementCancellation: ReplacementCancellation
    systemInitiatedCancellation: SystemInitiatedCancellation
    userInitiatedCancellation: UserInitiatedCancellation

@typing.type_check_only
class Comment(typing_extensions.TypedDict, total=False):
    developerComment: DeveloperComment
    userComment: UserComment

@typing.type_check_only
class ConvertRegionPricesRequest(typing_extensions.TypedDict, total=False):
    price: Money

@typing.type_check_only
class ConvertRegionPricesResponse(typing_extensions.TypedDict, total=False):
    convertedOtherRegionsPrice: ConvertedOtherRegionsPrice
    convertedRegionPrices: dict[str, typing.Any]

@typing.type_check_only
class ConvertedOtherRegionsPrice(typing_extensions.TypedDict, total=False):
    eurPrice: Money
    usdPrice: Money

@typing.type_check_only
class ConvertedRegionPrice(typing_extensions.TypedDict, total=False):
    price: Money
    regionCode: str
    taxAmount: Money

@typing.type_check_only
class CountryTargeting(typing_extensions.TypedDict, total=False):
    countries: _list[str]
    includeRestOfWorld: bool

@typing.type_check_only
class DeactivateBasePlanRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DeactivateSubscriptionOfferRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DeobfuscationFile(typing_extensions.TypedDict, total=False):
    symbolType: typing_extensions.Literal[
        "deobfuscationFileTypeUnspecified", "proguard", "nativeCode"
    ]

@typing.type_check_only
class DeobfuscationFilesUploadResponse(typing_extensions.TypedDict, total=False):
    deobfuscationFile: DeobfuscationFile

@typing.type_check_only
class DeveloperComment(typing_extensions.TypedDict, total=False):
    lastModified: Timestamp
    text: str

@typing.type_check_only
class DeveloperInitiatedCancellation(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DeviceGroup(typing_extensions.TypedDict, total=False):
    deviceSelectors: _list[DeviceSelector]
    name: str

@typing.type_check_only
class DeviceId(typing_extensions.TypedDict, total=False):
    buildBrand: str
    buildDevice: str

@typing.type_check_only
class DeviceMetadata(typing_extensions.TypedDict, total=False):
    cpuMake: str
    cpuModel: str
    deviceClass: str
    glEsVersion: int
    manufacturer: str
    nativePlatform: str
    productName: str
    ramMb: int
    screenDensityDpi: int
    screenHeightPx: int
    screenWidthPx: int

@typing.type_check_only
class DeviceRam(typing_extensions.TypedDict, total=False):
    maxBytes: str
    minBytes: str

@typing.type_check_only
class DeviceSelector(typing_extensions.TypedDict, total=False):
    deviceRam: DeviceRam
    excludedDeviceIds: _list[DeviceId]
    forbiddenSystemFeatures: _list[SystemFeature]
    includedDeviceIds: _list[DeviceId]
    requiredSystemFeatures: _list[SystemFeature]

@typing.type_check_only
class DeviceSpec(typing_extensions.TypedDict, total=False):
    screenDensity: int
    supportedAbis: _list[str]
    supportedLocales: _list[str]

@typing.type_check_only
class DeviceTier(typing_extensions.TypedDict, total=False):
    deviceGroupNames: _list[str]
    level: int

@typing.type_check_only
class DeviceTierConfig(typing_extensions.TypedDict, total=False):
    deviceGroups: _list[DeviceGroup]
    deviceTierConfigId: str
    deviceTierSet: DeviceTierSet

@typing.type_check_only
class DeviceTierSet(typing_extensions.TypedDict, total=False):
    deviceTiers: _list[DeviceTier]

@typing.type_check_only
class ExpansionFile(typing_extensions.TypedDict, total=False):
    fileSize: str
    referencesVersion: int

@typing.type_check_only
class ExpansionFilesUploadResponse(typing_extensions.TypedDict, total=False):
    expansionFile: ExpansionFile

@typing.type_check_only
class ExternalAccountIdentifiers(typing_extensions.TypedDict, total=False):
    externalAccountId: str
    obfuscatedExternalAccountId: str
    obfuscatedExternalProfileId: str

@typing.type_check_only
class ExternallyHostedApk(typing_extensions.TypedDict, total=False):
    applicationLabel: str
    certificateBase64s: _list[str]
    externallyHostedUrl: str
    fileSha1Base64: str
    fileSha256Base64: str
    fileSize: str
    iconBase64: str
    maximumSdk: int
    minimumSdk: int
    nativeCodes: _list[str]
    packageName: str
    usesFeatures: _list[str]
    usesPermissions: _list[UsesPermission]
    versionCode: int
    versionName: str

@typing.type_check_only
class GeneratedApksListResponse(typing_extensions.TypedDict, total=False):
    generatedApks: _list[GeneratedApksPerSigningKey]

@typing.type_check_only
class GeneratedApksPerSigningKey(typing_extensions.TypedDict, total=False):
    certificateSha256Hash: str
    generatedAssetPackSlices: _list[GeneratedAssetPackSlice]
    generatedSplitApks: _list[GeneratedSplitApk]
    generatedStandaloneApks: _list[GeneratedStandaloneApk]
    generatedUniversalApk: GeneratedUniversalApk

@typing.type_check_only
class GeneratedAssetPackSlice(typing_extensions.TypedDict, total=False):
    downloadId: str
    moduleName: str
    sliceId: str
    version: str

@typing.type_check_only
class GeneratedSplitApk(typing_extensions.TypedDict, total=False):
    downloadId: str
    moduleName: str
    splitId: str
    variantId: int

@typing.type_check_only
class GeneratedStandaloneApk(typing_extensions.TypedDict, total=False):
    downloadId: str
    variantId: int

@typing.type_check_only
class GeneratedUniversalApk(typing_extensions.TypedDict, total=False):
    downloadId: str

@typing.type_check_only
class Grant(typing_extensions.TypedDict, total=False):
    appLevelPermissions: _list[str]
    name: str
    packageName: str

@typing.type_check_only
class Image(typing_extensions.TypedDict, total=False):
    id: str
    sha1: str
    sha256: str
    url: str

@typing.type_check_only
class ImagesDeleteAllResponse(typing_extensions.TypedDict, total=False):
    deleted: _list[Image]

@typing.type_check_only
class ImagesListResponse(typing_extensions.TypedDict, total=False):
    images: _list[Image]

@typing.type_check_only
class ImagesUploadResponse(typing_extensions.TypedDict, total=False):
    image: Image

@typing.type_check_only
class InAppProduct(typing_extensions.TypedDict, total=False):
    defaultLanguage: str
    defaultPrice: Price
    gracePeriod: str
    listings: dict[str, typing.Any]
    managedProductTaxesAndComplianceSettings: ManagedProductTaxAndComplianceSettings
    packageName: str
    prices: dict[str, typing.Any]
    purchaseType: typing_extensions.Literal[
        "purchaseTypeUnspecified", "managedUser", "subscription"
    ]
    sku: str
    status: typing_extensions.Literal["statusUnspecified", "active", "inactive"]
    subscriptionPeriod: str
    subscriptionTaxesAndComplianceSettings: SubscriptionTaxAndComplianceSettings
    trialPeriod: str

@typing.type_check_only
class InAppProductListing(typing_extensions.TypedDict, total=False):
    benefits: _list[str]
    description: str
    title: str

@typing.type_check_only
class InappproductsListResponse(typing_extensions.TypedDict, total=False):
    inappproduct: _list[InAppProduct]
    kind: str
    pageInfo: PageInfo
    tokenPagination: TokenPagination

@typing.type_check_only
class InternalAppSharingArtifact(typing_extensions.TypedDict, total=False):
    certificateFingerprint: str
    downloadUrl: str
    sha256: str

@typing.type_check_only
class IntroductoryPriceInfo(typing_extensions.TypedDict, total=False):
    introductoryPriceAmountMicros: str
    introductoryPriceCurrencyCode: str
    introductoryPriceCycles: int
    introductoryPricePeriod: str

@typing.type_check_only
class ListDeviceTierConfigsResponse(typing_extensions.TypedDict, total=False):
    deviceTierConfigs: _list[DeviceTierConfig]
    nextPageToken: str

@typing.type_check_only
class ListSubscriptionOffersResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    subscriptionOffers: _list[SubscriptionOffer]

@typing.type_check_only
class ListSubscriptionsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    subscriptions: _list[Subscription]

@typing.type_check_only
class ListUsersResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    users: _list[User]

@typing.type_check_only
class Listing(typing_extensions.TypedDict, total=False):
    fullDescription: str
    language: str
    shortDescription: str
    title: str
    video: str

@typing.type_check_only
class ListingsListResponse(typing_extensions.TypedDict, total=False):
    kind: str
    listings: _list[Listing]

@typing.type_check_only
class LocalizedText(typing_extensions.TypedDict, total=False):
    language: str
    text: str

@typing.type_check_only
class ManagedProductTaxAndComplianceSettings(typing_extensions.TypedDict, total=False):
    eeaWithdrawalRightType: typing_extensions.Literal[
        "WITHDRAWAL_RIGHT_TYPE_UNSPECIFIED",
        "WITHDRAWAL_RIGHT_DIGITAL_CONTENT",
        "WITHDRAWAL_RIGHT_SERVICE",
    ]
    taxRateInfoByRegionCode: dict[str, typing.Any]

@typing.type_check_only
class MigrateBasePlanPricesRequest(typing_extensions.TypedDict, total=False):
    regionalPriceMigrations: _list[RegionalPriceMigrationConfig]
    regionsVersion: RegionsVersion

@typing.type_check_only
class MigrateBasePlanPricesResponse(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Money(typing_extensions.TypedDict, total=False):
    currencyCode: str
    nanos: int
    units: str

@typing.type_check_only
class OfferTag(typing_extensions.TypedDict, total=False):
    tag: str

@typing.type_check_only
class OtherRegionsBasePlanConfig(typing_extensions.TypedDict, total=False):
    eurPrice: Money
    newSubscriberAvailability: bool
    usdPrice: Money

@typing.type_check_only
class OtherRegionsSubscriptionOfferConfig(typing_extensions.TypedDict, total=False):
    otherRegionsNewSubscriberAvailability: bool

@typing.type_check_only
class OtherRegionsSubscriptionOfferPhaseConfig(
    typing_extensions.TypedDict, total=False
):
    absoluteDiscounts: OtherRegionsSubscriptionOfferPhasePrices
    otherRegionsPrices: OtherRegionsSubscriptionOfferPhasePrices
    relativeDiscount: float

@typing.type_check_only
class OtherRegionsSubscriptionOfferPhasePrices(
    typing_extensions.TypedDict, total=False
):
    eurPrice: Money
    usdPrice: Money

@typing.type_check_only
class PageInfo(typing_extensions.TypedDict, total=False):
    resultPerPage: int
    startIndex: int
    totalResults: int

@typing.type_check_only
class PausedStateContext(typing_extensions.TypedDict, total=False):
    autoResumeTime: str

@typing.type_check_only
class PrepaidBasePlanType(typing_extensions.TypedDict, total=False):
    billingPeriodDuration: str
    timeExtension: typing_extensions.Literal[
        "TIME_EXTENSION_UNSPECIFIED", "TIME_EXTENSION_ACTIVE", "TIME_EXTENSION_INACTIVE"
    ]

@typing.type_check_only
class PrepaidPlan(typing_extensions.TypedDict, total=False):
    allowExtendAfterTime: str

@typing.type_check_only
class Price(typing_extensions.TypedDict, total=False):
    currency: str
    priceMicros: str

@typing.type_check_only
class ProductPurchase(typing_extensions.TypedDict, total=False):
    acknowledgementState: int
    consumptionState: int
    developerPayload: str
    kind: str
    obfuscatedExternalAccountId: str
    obfuscatedExternalProfileId: str
    orderId: str
    productId: str
    purchaseState: int
    purchaseTimeMillis: str
    purchaseToken: str
    purchaseType: int
    quantity: int
    regionCode: str

@typing.type_check_only
class ProductPurchasesAcknowledgeRequest(typing_extensions.TypedDict, total=False):
    developerPayload: str

@typing.type_check_only
class RegionalBasePlanConfig(typing_extensions.TypedDict, total=False):
    newSubscriberAvailability: bool
    price: Money
    regionCode: str

@typing.type_check_only
class RegionalPriceMigrationConfig(typing_extensions.TypedDict, total=False):
    oldestAllowedPriceVersionTime: str
    regionCode: str

@typing.type_check_only
class RegionalSubscriptionOfferConfig(typing_extensions.TypedDict, total=False):
    newSubscriberAvailability: bool
    regionCode: str

@typing.type_check_only
class RegionalSubscriptionOfferPhaseConfig(typing_extensions.TypedDict, total=False):
    absoluteDiscount: Money
    price: Money
    regionCode: str
    relativeDiscount: float

@typing.type_check_only
class RegionalTaxRateInfo(typing_extensions.TypedDict, total=False):
    eligibleForStreamingServiceTaxRate: bool
    taxTier: typing_extensions.Literal[
        "TAX_TIER_UNSPECIFIED",
        "TAX_TIER_BOOKS_1",
        "TAX_TIER_NEWS_1",
        "TAX_TIER_NEWS_2",
        "TAX_TIER_MUSIC_OR_AUDIO_1",
        "TAX_TIER_LIVE_OR_BROADCAST_1",
    ]

@typing.type_check_only
class RegionsVersion(typing_extensions.TypedDict, total=False):
    version: str

@typing.type_check_only
class ReplacementCancellation(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Review(typing_extensions.TypedDict, total=False):
    authorName: str
    comments: _list[Comment]
    reviewId: str

@typing.type_check_only
class ReviewReplyResult(typing_extensions.TypedDict, total=False):
    lastEdited: Timestamp
    replyText: str

@typing.type_check_only
class ReviewsListResponse(typing_extensions.TypedDict, total=False):
    pageInfo: PageInfo
    reviews: _list[Review]
    tokenPagination: TokenPagination

@typing.type_check_only
class ReviewsReplyRequest(typing_extensions.TypedDict, total=False):
    replyText: str

@typing.type_check_only
class ReviewsReplyResponse(typing_extensions.TypedDict, total=False):
    result: ReviewReplyResult

@typing.type_check_only
class SubscribeWithGoogleInfo(typing_extensions.TypedDict, total=False):
    emailAddress: str
    familyName: str
    givenName: str
    profileId: str
    profileName: str

@typing.type_check_only
class Subscription(typing_extensions.TypedDict, total=False):
    archived: bool
    basePlans: _list[BasePlan]
    listings: _list[SubscriptionListing]
    packageName: str
    productId: str
    taxAndComplianceSettings: SubscriptionTaxAndComplianceSettings

@typing.type_check_only
class SubscriptionCancelSurveyResult(typing_extensions.TypedDict, total=False):
    cancelSurveyReason: int
    userInputCancelReason: str

@typing.type_check_only
class SubscriptionDeferralInfo(typing_extensions.TypedDict, total=False):
    desiredExpiryTimeMillis: str
    expectedExpiryTimeMillis: str

@typing.type_check_only
class SubscriptionListing(typing_extensions.TypedDict, total=False):
    benefits: _list[str]
    description: str
    languageCode: str
    title: str

@typing.type_check_only
class SubscriptionOffer(typing_extensions.TypedDict, total=False):
    basePlanId: str
    offerId: str
    offerTags: _list[OfferTag]
    otherRegionsConfig: OtherRegionsSubscriptionOfferConfig
    packageName: str
    phases: _list[SubscriptionOfferPhase]
    productId: str
    regionalConfigs: _list[RegionalSubscriptionOfferConfig]
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "DRAFT", "ACTIVE", "INACTIVE"]
    targeting: SubscriptionOfferTargeting

@typing.type_check_only
class SubscriptionOfferPhase(typing_extensions.TypedDict, total=False):
    duration: str
    otherRegionsConfig: OtherRegionsSubscriptionOfferPhaseConfig
    recurrenceCount: int
    regionalConfigs: _list[RegionalSubscriptionOfferPhaseConfig]

@typing.type_check_only
class SubscriptionOfferTargeting(typing_extensions.TypedDict, total=False):
    acquisitionRule: AcquisitionTargetingRule
    upgradeRule: UpgradeTargetingRule

@typing.type_check_only
class SubscriptionPriceChange(typing_extensions.TypedDict, total=False):
    newPrice: Price
    state: int

@typing.type_check_only
class SubscriptionPurchase(typing_extensions.TypedDict, total=False):
    acknowledgementState: int
    autoRenewing: bool
    autoResumeTimeMillis: str
    cancelReason: int
    cancelSurveyResult: SubscriptionCancelSurveyResult
    countryCode: str
    developerPayload: str
    emailAddress: str
    expiryTimeMillis: str
    externalAccountId: str
    familyName: str
    givenName: str
    introductoryPriceInfo: IntroductoryPriceInfo
    kind: str
    linkedPurchaseToken: str
    obfuscatedExternalAccountId: str
    obfuscatedExternalProfileId: str
    orderId: str
    paymentState: int
    priceAmountMicros: str
    priceChange: SubscriptionPriceChange
    priceCurrencyCode: str
    profileId: str
    profileName: str
    promotionCode: str
    promotionType: int
    purchaseType: int
    startTimeMillis: str
    userCancellationTimeMillis: str

@typing.type_check_only
class SubscriptionPurchaseLineItem(typing_extensions.TypedDict, total=False):
    autoRenewingPlan: AutoRenewingPlan
    expiryTime: str
    prepaidPlan: PrepaidPlan
    productId: str

@typing.type_check_only
class SubscriptionPurchaseV2(typing_extensions.TypedDict, total=False):
    acknowledgementState: typing_extensions.Literal[
        "ACKNOWLEDGEMENT_STATE_UNSPECIFIED",
        "ACKNOWLEDGEMENT_STATE_PENDING",
        "ACKNOWLEDGEMENT_STATE_ACKNOWLEDGED",
    ]
    canceledStateContext: CanceledStateContext
    externalAccountIdentifiers: ExternalAccountIdentifiers
    kind: str
    latestOrderId: str
    lineItems: _list[SubscriptionPurchaseLineItem]
    linkedPurchaseToken: str
    pausedStateContext: PausedStateContext
    regionCode: str
    startTime: str
    subscribeWithGoogleInfo: SubscribeWithGoogleInfo
    subscriptionState: typing_extensions.Literal[
        "SUBSCRIPTION_STATE_UNSPECIFIED",
        "SUBSCRIPTION_STATE_PENDING",
        "SUBSCRIPTION_STATE_ACTIVE",
        "SUBSCRIPTION_STATE_PAUSED",
        "SUBSCRIPTION_STATE_IN_GRACE_PERIOD",
        "SUBSCRIPTION_STATE_ON_HOLD",
        "SUBSCRIPTION_STATE_CANCELED",
        "SUBSCRIPTION_STATE_EXPIRED",
    ]
    testPurchase: TestPurchase

@typing.type_check_only
class SubscriptionPurchasesAcknowledgeRequest(typing_extensions.TypedDict, total=False):
    developerPayload: str

@typing.type_check_only
class SubscriptionPurchasesDeferRequest(typing_extensions.TypedDict, total=False):
    deferralInfo: SubscriptionDeferralInfo

@typing.type_check_only
class SubscriptionPurchasesDeferResponse(typing_extensions.TypedDict, total=False):
    newExpiryTimeMillis: str

@typing.type_check_only
class SubscriptionTaxAndComplianceSettings(typing_extensions.TypedDict, total=False):
    eeaWithdrawalRightType: typing_extensions.Literal[
        "WITHDRAWAL_RIGHT_TYPE_UNSPECIFIED",
        "WITHDRAWAL_RIGHT_DIGITAL_CONTENT",
        "WITHDRAWAL_RIGHT_SERVICE",
    ]
    taxRateInfoByRegionCode: dict[str, typing.Any]

@typing.type_check_only
class SystemApksListResponse(typing_extensions.TypedDict, total=False):
    variants: _list[Variant]

@typing.type_check_only
class SystemFeature(typing_extensions.TypedDict, total=False):
    name: str

@typing.type_check_only
class SystemInitiatedCancellation(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class TargetingRuleScope(typing_extensions.TypedDict, total=False):
    specificSubscriptionInApp: str

@typing.type_check_only
class TestPurchase(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Testers(typing_extensions.TypedDict, total=False):
    googleGroups: _list[str]

@typing.type_check_only
class Timestamp(typing_extensions.TypedDict, total=False):
    nanos: int
    seconds: str

@typing.type_check_only
class TokenPagination(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    previousPageToken: str

@typing.type_check_only
class Track(typing_extensions.TypedDict, total=False):
    releases: _list[TrackRelease]
    track: str

@typing.type_check_only
class TrackCountryAvailability(typing_extensions.TypedDict, total=False):
    countries: _list[TrackTargetedCountry]
    restOfWorld: bool
    syncWithProduction: bool

@typing.type_check_only
class TrackRelease(typing_extensions.TypedDict, total=False):
    countryTargeting: CountryTargeting
    inAppUpdatePriority: int
    name: str
    releaseNotes: _list[LocalizedText]
    status: typing_extensions.Literal[
        "statusUnspecified", "draft", "inProgress", "halted", "completed"
    ]
    userFraction: float
    versionCodes: _list[str]

@typing.type_check_only
class TrackTargetedCountry(typing_extensions.TypedDict, total=False):
    countryCode: str

@typing.type_check_only
class TracksListResponse(typing_extensions.TypedDict, total=False):
    kind: str
    tracks: _list[Track]

@typing.type_check_only
class UpgradeTargetingRule(typing_extensions.TypedDict, total=False):
    billingPeriodDuration: str
    oncePerUser: bool
    scope: TargetingRuleScope

@typing.type_check_only
class User(typing_extensions.TypedDict, total=False):
    accessState: typing_extensions.Literal[
        "ACCESS_STATE_UNSPECIFIED",
        "INVITED",
        "INVITATION_EXPIRED",
        "ACCESS_GRANTED",
        "ACCESS_EXPIRED",
    ]
    developerAccountPermissions: _list[str]
    email: str
    expirationTime: str
    grants: _list[Grant]
    name: str
    partial: bool

@typing.type_check_only
class UserComment(typing_extensions.TypedDict, total=False):
    androidOsVersion: int
    appVersionCode: int
    appVersionName: str
    device: str
    deviceMetadata: DeviceMetadata
    lastModified: Timestamp
    originalText: str
    reviewerLanguage: str
    starRating: int
    text: str
    thumbsDownCount: int
    thumbsUpCount: int

@typing.type_check_only
class UserInitiatedCancellation(typing_extensions.TypedDict, total=False):
    cancelSurveyResult: CancelSurveyResult
    cancelTime: str

@typing.type_check_only
class UsesPermission(typing_extensions.TypedDict, total=False):
    maxSdkVersion: int
    name: str

@typing.type_check_only
class Variant(typing_extensions.TypedDict, total=False):
    deviceSpec: DeviceSpec
    variantId: int

@typing.type_check_only
class VoidedPurchase(typing_extensions.TypedDict, total=False):
    kind: str
    orderId: str
    purchaseTimeMillis: str
    purchaseToken: str
    voidedReason: int
    voidedSource: int
    voidedTimeMillis: str

@typing.type_check_only
class VoidedPurchasesListResponse(typing_extensions.TypedDict, total=False):
    pageInfo: PageInfo
    tokenPagination: TokenPagination
    voidedPurchases: _list[VoidedPurchase]
